tomography Documentation
========================

Welcome to the document of the tomography. The package is a toolbox for the data collection, processing, analysis
and visualization in the crystal mapping. The crystal mapping is a technique to reveal the spatial or oriental
distribution of single crystals using a series of x-ray diffraction data. There are an old algorithm and a new
algorithm to do this. The package includes both of them. It is recommended to use the new one.

.. toctree::
   :maxdepth: 2

   installation
   experiment
   old_algorithm
   new_algorithm
   apis
   min_versions
